from rdflib import Namespace

# OntoPiA Namespaces

L0 = Namespace("https://w3id.org/italia/onto/l0/")
TRANSP = Namespace("https://w3id.org/italia/onto/Transparency/")
TI = Namespace("https://w3id.org/italia/onto/TI/")
SM = Namespace("https://w3id.org/italia/onto/SM/")
ROUTE = Namespace("https://w3id.org/italia/onto/Route/")
RO = Namespace("https://w3id.org/italia/onto/RO/")
PUBC = Namespace("https://w3id.org/italia/onto/PublicContract/")
PROJ = Namespace("https://w3id.org/italia/onto/Project/")
POT = Namespace("https://w3id.org/italia/onto/POT/")
POI = Namespace("https://w3id.org/italia/onto/POI/")
PARK = Namespace("https://w3id.org/italia/onto/PARK/")
MU = Namespace("https://w3id.org/italia/onto/MU/")
LANG = Namespace("https://w3id.org/italia/onto/Language/")
IOT = Namespace("https://w3id.org/italia/onto/IoT/")
INDIC = Namespace("https://w3id.org/italia/onto/Indicator/")
HER = Namespace("https://w3id.org/italia/onto/HER/")
CULTHER = Namespace("https://w3id.org/italia/onto/CulturalHeritage/")
CPV = Namespace("https://w3id.org/italia/onto/CPV/")
CPSV = Namespace("https://w3id.org/italia/onto/CPSV/")
CPEV = Namespace("https://w3id.org/italia/onto/CPEV/")
COV = Namespace("https://w3id.org/italia/onto/COV/")
CLV = Namespace("https://w3id.org/italia/onto/CLV/")
PATHS = Namespace("https://w3id.org/italia/onto/AtlasOfPaths/")
ACOND = Namespace("https://w3id.org/italia/onto/AccessCondition/")
ACCO = Namespace("https://w3id.org/italia/onto/ACCO/")

# OntoPiA Controlled Vocabularies

EVENTS_TYPE = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/public-event-types/")
LICENSES = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/licenses/")
GEO_DISTRIBUTION = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/territorial-classifications/geographical-distribution/")
REGIONS = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/territorial-classifications/regions/")
PROVINCES = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/territorial-classifications/provinces/")
COUNTRIES = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/territorial-classifications/countries/")  # Note: only /italy available
CITIES = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/territorial-classifications/cities/")
POI_CLASSIFICATION = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/poi-category-classification/")
ACCO_STAR_RATINGS = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-accommodation-facilities/accommodation-star-rating/")
ACCO_TYPES = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-accommodation-facilities/accommodation-typology/")
PERSON_EDULEVEL = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-people/education-level/")
PERSON_TITLE = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-people/person-title/")
PERSON_PARENTAL_REL = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-people/parental-relationship-types/")
ORG_LEGAL_STATUS = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-organizations/legal-status/")
ORG_ATECO = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-organizations/ateco-2007/")
ORG_S13 = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-organizations/S13/")
CUL_SUBJ = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-culture/subject-disciplines/")
CUL_PLACES = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-culture/cultural-interest-places/")
ROUTE_TYPES = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-routes/route-types/")
AUTH_TYPES = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-public-services/authentication-type/")
EROGATION_CHANNELS = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-public-services/channel/")
INTERACT_LEVEL = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-public-services/interactivity-level/")
IO_SERVICE = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-public-services/service-input-output/")
LIFE_EVENTS = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-public-services/life-business-event/life-event/")
BUSINESS_EVENTS = Namespace(
    "https://w3id.org/italia/controlled-vocabulary/classifications-for-public-services/life-business-event/business-event/")
